@@ -200,7 +200,13 @@ qx.Class.define("callbackery.ui.plugin.Action", {
             form.setParameter('key',btCfg.key);
             form.setLayout(new qx.ui.layout.HBox());
             this.add(form);
-            var file = new uploadwidget.UploadButton('file', this['tr'](btCfg.label));
+            var file;
+            if (btCfg.btnClass == 'toolbar') {
+                file = new uploadwidget.UploadToolbarButton('file', this['tr'](btCfg.label));
+            }
+            else {
+                file = new uploadwidget.UploadButton('file', this['tr'](btCfg.label));
+            }
             form.add(file);
             file.addListener('execute',function(e){
                 var formData = getFormData();
